@@ -297,7 +297,7 @@ class LipidInteraction:
         return
 
     def compute_residue_koff(self, residue_id=None, nbootstrap=10, initial_guess=[1., 1., 1., 1.],
-                             save_dir=None, print_data=True, plot_data=True):
+                             save_dir=None, print_data=True, plot_data=True, fig_close=True):
         """Calculate interaction koff for residues.
 
         Parameters
@@ -308,6 +308,7 @@ class LipidInteraction:
         save_dir : str, optional, default=None
         print_data : bool, optional, default=True
         plot_data : bool, optional, default=True
+        fig_close : bool, optional, default=True
 
         Returns
         ---------
@@ -364,7 +365,7 @@ class LipidInteraction:
                     plot_koff(durations, properties["delta_t_list"], properties["survival_rates"],
                               properties["n_fitted"], survival_rates_bootstraps=properties["survival_rates_boot_set"],
                               fig_fn=os.path.join(koff_dir, "{}.pdf".format(residue)), title=residue,
-                              timeunit=self._timeunit, t_total=t_total, text=text)
+                              timeunit=self._timeunit, t_total=t_total, text=text, fig_close=fig_close)
                 if print_data:
                     print("{:15s}: {}".format("Residue", residue))
                     print("{:15s}: {}".format("Residue ID", residue_id))
@@ -406,7 +407,7 @@ class LipidInteraction:
         if len(self._node_list) == 0:
             print("No binding site detected!!")
         else:
-            residue_BS_identifiers = np.ones(self._nresi_per_protein) * -1
+            residue_BS_identifiers = np.ones(self._nresi_per_protein, dtype=int) * -1
             for bs_id, nodes in enumerate(self._node_list):
                 residue_BS_identifiers[nodes] = bs_id
             # update dataset
@@ -429,7 +430,8 @@ class LipidInteraction:
         return node_list
 
     def compute_site_koff(self, binding_site_id=None, nbootstrap=10, initial_guess=[1., 1., 1., 1.],
-                          save_dir=None, print_data=True, plot_data=True, sort_residue="Residence Time"):
+                          save_dir=None, print_data=True, plot_data=True, sort_residue="Residence Time",
+                          fig_close=True):
         """Calculate interactions for binding sites.
 
         Parameters
@@ -524,7 +526,7 @@ class LipidInteraction:
                 plot_koff(durations, properties_BS["delta_t_list"], properties_BS["survival_rates"],
                           properties_BS["n_fitted"], survival_rates_bootstraps=properties_BS["survival_rates_boot_set"],
                           fig_fn=os.path.join(BS_dir, f"BS_id{bs_id}.pdf"), title=f"Binding Site {bs_id}",
-                          timeunit=self._timeunit, t_total=t_total, text=text)
+                          timeunit=self._timeunit, t_total=t_total, text=text, fig_close=fig_close)
         # update dataset
         self.dataset["Binding Site Koff"] = koff_BS_per_residue
         self.dataset["Binding Site Residence Time"] = res_time_BS_per_residue
@@ -547,7 +549,7 @@ class LipidInteraction:
 
     def analyze_bound_poses(self, binding_site_id=None, n_top_poses=3, pose_format="gro", score_weights=None,
                             kde_bw=0.15, pca_component=0.95, plot_rmsd=True, save_dir=None,
-                            n_clusters="auto", eps=None, min_samples=None, metric="euclidean"):
+                            n_clusters="auto", eps=None, min_samples=None, metric="euclidean", fig_close=False):
         """Analyze binding poses.
 
         Parameters
@@ -636,10 +638,10 @@ class LipidInteraction:
         # plot RMSD
         if plot_rmsd and n_top_poses > 0:
             plot_binding_site_data(pose_rmsd_data, os.path.join(pose_dir, "Pose_RMSD_violinplot.pdf"),
-                                   title="{}".format(self._lipid), ylabel="RMSD (nm)")
+                                   title="{}".format(self._lipid), ylabel="RMSD (nm)", fig_close=fig_close)
         return pose_pool, pose_rmsd_data
 
-    def compute_surface_area(self, binding_site_id=None, radii=None, plot_data=True, save_dir=None):
+    def compute_surface_area(self, binding_site_id=None, radii=None, plot_data=True, save_dir=None, fig_close=False):
         """Calculate binding site surface areas.
 
         Parameters
@@ -685,12 +687,13 @@ class LipidInteraction:
                 surface_area_dir = check_dir(self._save_dir)
             plot_surface_area(surface_area_data,
                               os.path.join(surface_area_dir, "Surface_Area_{}_timeseries.pdf".format(self._lipid)),
-                              timeunit=self._timeunit)
+                              timeunit=self._timeunit, fig_close=fig_close)
             selected_columns = [column for column in surface_area_data.columns if column != "Time"]
             surface_data_noTimeSeries = surface_area_data[selected_columns]
             plot_binding_site_data(surface_data_noTimeSeries,
                                    os.path.join(surface_area_dir, "Surface_Area_{}_violinplot.pdf".format(self._lipid)),
-                                   title="{}".format(self._lipid), ylabel=r"Surface Area (nm$^2$)")
+                                   title="{}".format(self._lipid), ylabel=r"Surface Area (nm$^2$)",
+                                   fig_close=fig_close)
         return surface_area_data
 
     def write_site_info(self, sort_residue="Residence Time", save_dir=None, fn_info=None):
@@ -778,7 +781,7 @@ class LipidInteraction:
                            self._lipid, len(self._node_list))
         return
 
-    def plot(self, item, save_dir=None, gap=200):
+    def plot(self, item, save_dir=None, gap=200, fig_close=False):
         """Plot interactions.
 
         Parameters
@@ -804,16 +807,17 @@ class LipidInteraction:
             title = "{} {}".format(self._lipid, item)
             fig_fn = os.path.join(figure_dir, "{}.pdf".format("_".join(item.split())))
             residue_index = np.array([int(re.findall("^[0-9]+", residue)[0]) for residue in self._residue_list])
-            plot_residue_data(residue_index, data, gap=gap, ylabel=ylabel, fn=fig_fn, title=title)
+            plot_residue_data(residue_index, data, gap=gap, ylabel=ylabel, fn=fig_fn, title=title,
+                              fig_close=fig_close)
 
         if item == "CorrCoef":
             residue_index = np.array([int(re.findall("^[0-9]+", residue)[0]) for residue in self._residue_list])
             plot_corrcoef(self.interaction_corrcoef, residue_index, fn=os.path.join(figure_dir, "CorrCoef.pdf"),
-                          title="{} Correlation Coeffient".format(self._lipid))
+                          title="{} Correlation Coeffient".format(self._lipid), fig_close=fig_close)
 
         return
 
-    def plot_logo(self, item, save_dir=None, gap=2000, letter_map=None, color_scheme="chemistry"):
+    def plot_logo(self, item, save_dir=None, gap=2000, letter_map=None, color_scheme="chemistry", fig_close=False):
         """Plot interactions using logomaker.
 
         Parameters
@@ -852,7 +856,8 @@ class LipidInteraction:
             title = "{} {} Logo".format(self._lipid, item)
             fig_fn = os.path.join(figure_dir, "{}_logo.pdf".format("_".join(item.split())))
             plot_residue_data_logos(residue_index, resname_set, data, ylabel=ylabel,
-                                    fn=fig_fn, title=title, letter_map=letter_map, color_scheme=color_scheme)
+                                    fn=fig_fn, title=title, letter_map=letter_map, color_scheme=color_scheme,
+                                    fig_close=fig_close)
         else:
             print("Invalid input for item!")
 
@@ -923,7 +928,7 @@ class LipidInteraction:
 
     def _format_koff_text(self, properties):
         """Format text for koff plot. """
-        tu = "ns" if self._timeunit == "ns" else r"$\mu$ s"
+        tu = "ns" if self._timeunit == "ns" else r"$\mu$s"
         text = "{:18s} = {:.3f} {:2s}$^{{-1}} $\n".format("$k_{{off1}}$", properties["ks"][0], tu)
         text += "{:18s} = {:.3f} {:2s}$^{{-1}} $\n".format("$k_{{off2}}$", properties["ks"][1], tu)
         text += "{:14s} = {:.4f}\n".format("$R^2$", properties["r_squared"])
